@@ -1,10 +1,7 @@
 import os
 import sys
 import json
-try:
-    from ruamel.ordereddict import ordereddict as OrderedDict
-except ImportError:  # nocv
-    from collections import OrderedDict
+from collections import OrderedDict
 from ansible.config.manager import (
     ConfigManager, Setting, find_ini_config_file, to_native
 )
