@@ -1,4 +1,3 @@
-from __future__ import print_function, unicode_literals
 import os
 import sys
 import signal
@@ -21,7 +20,8 @@ def print_output(output):
     if output:
         try:
             output = output.decode('utf-8')
-        except:
+        except:  # nocv
+            # No coverage because depend on LC_ALL and LANG env variables
             return False
         print(output, end='')
         sys.stdout.flush()
@@ -45,7 +45,8 @@ def handler(args=sys.argv[1:], parser=get_parser()):
             print_output(output)
             break
         if not print_output(output):
-            continue
+            # No coverage because depend on LC_ALL and LANG env variables
+            continue  # nocv
         rc = process.poll()
 
     process.stdout.close()
